<?php

namespace Drupal\sync_clients\SyncClientPause;

use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Implements Sync Client Pause object.
 *
 * Allows for easier handling/passing on of Sync Client Pause information.
 */
class SyncClientPause implements SyncClientPauseInterface {

  use StringTranslationTrait;

  /**
   * Reason fallback value.
   *
   * @var string
   */
  const REASON_DEFAULT = 'N/A';

  /**
   * The pause cause.
   *
   * @var string
   */
  protected string $cause;

  /**
   * The pause reason.
   *
   * @var string
   */
  protected string $reason;

  /**
   * SyncClientPause constructor.
   *
   * @param string $cause
   *   The pause cause. Any of the PAUSE_CAUSE_[X] constants.
   * @param string $reason
   *   Optional, but recommended, reason for why the sync was paused.
   */
  public function __construct(string $cause, string $reason = self::REASON_DEFAULT) {
    $this->cause = $cause;
    $this->reason = $reason;
  }

  /**
   * {@inheritdoc}
   */
  public function getCause(): string {
    return $this->cause;
  }

  /**
   * {@inheritdoc}
   */
  public function getPauseMessage(): string {

    $params = [
      '@cause' => $this->cause,
      '@reason' => $this->reason,
    ];

    return match ($this->cause) {
      static::PAUSE_CAUSE_FORCED => $this->t('Sync has been forcefully paused. Reason for last pause trigger: @reason', $params),
      static::PAUSE_CAUSE_MANUAL => $this->t('@reason', $params),
      default => $this->t('Sync is paused due to "@cause" and reason: @reason', $params),
    };
  }

  /**
   * {@inheritdoc}
   */
  public function isForced(): bool {
    return $this->cause === static::PAUSE_CAUSE_FORCED;
  }

  /**
   * {@inheritdoc}
   */
  public function isManual(): bool {
    return $this->cause === static::PAUSE_CAUSE_MANUAL;
  }

}
